#
# Conditional build:
%bcond_with	tests		# build with tests
%define		kdeappsver	23.08.5
%define		kframever	5.94.0
%define		qtver		5.15.2
%define		kaname		step
Summary:	step
Name:		ka5-%{kaname}
Version:	23.08.5
Release:	1
License:	GPL v2+/LGPL v2.1+
Group:		X11/Applications
Source0:	https://download.kde.org/stable/release-service/%{kdeappsver}/src/%{kaname}-%{version}.tar.xz
# Source0-md5:	f56500f0f96a02b633e9f326425fb833
Patch0:		python.patch
URL:		http://www.kde.org/
BuildRequires:	Qt5Core-devel >= %{qtver}
BuildRequires:	Qt5Gui-devel >= 5.11.1
BuildRequires:	Qt5OpenGL-devel
BuildRequires:	Qt5Svg-devel
BuildRequires:	Qt5Test-devel
BuildRequires:	Qt5Widgets-devel >= 5.11.1
BuildRequires:	Qt5Xml-devel
BuildRequires:	cmake >= 3.20
BuildRequires:	eigen3 >= 3.2.2
BuildRequires:	gettext-devel
BuildRequires:	kf5-extra-cmake-modules >= %{kframever}
BuildRequires:	kf5-kconfig-devel >= %{kframever}
BuildRequires:	kf5-kcrash-devel >= %{kframever}
BuildRequires:	kf5-khtml-devel >= %{kframever}
BuildRequires:	kf5-kiconthemes-devel >= %{kframever}
BuildRequires:	kf5-knewstuff-devel >= %{kframever}
BuildRequires:	kf5-kplotting-devel >= %{kframever}
BuildRequires:	ninja
BuildRequires:	qt5-build >= %{qtver}
BuildRequires:	rpmbuild(macros) >= 1.164
BuildRequires:	shared-mime-info
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Step is an interactive physical simulator. It allows you to explore
the physical world through simulations.

Features

- Classical mechanical simulation in two dimensions
- Particles, springs with damping, gravitational and coulomb forces
- Rigid bodies
- Collision detection (currently only discrete) and handling
- Soft (deformable) bodies simulated as user-editable
  particles-springs system, sound waves
- Molecular dynamics (currently using Lennard-Jones potential): gas
  and liquid, condensation and evaporation, calculation of macroscopic
  quantities and their variances
- Units conversion and expression calculation: you can enter something
  like "(2 days + 3 hours) * 80 km/h" and it will be accepted as
  distance value (requires libqalculate)
- Errors calculation and propagation: you can enter values like "1.3 ±
  0.2" for any property and errors for all dependent properties will be
  calculated using statistical formulas
- Solver error estimation: errors introduced by the solver is
  calculated and added to user-entered errors
- Several different solvers: up to 8th order, explicit and implicit,
  with or without adaptive timestep (most of the solvers require the GSL
  library)
- Controller tool to easily control properties during simulation (even
  with custom keyboard shortcuts)
- Tools to visualize results: graph, meter, tracer
- Context information for all objects, integrated wikipedia browser
- Collection of example experiments, more can be downloaded with
  KNewStuff
- Integrated tutorials

%prep
%setup -q -n %{kaname}-%{version}
%patch0 -p1

%build
%cmake \
	-B build \
	-G Ninja \
	%{!?with_tests:-DBUILD_TESTING=OFF} \
	-DHTML_INSTALL_DIR=%{_kdedocdir} \
	-DKDE_INSTALL_USE_QT_SYS_PATHS=ON
%ninja_build -C build

%if %{with tests}
ctest --test-dir build
%endif


%install
rm -rf $RPM_BUILD_ROOT
%ninja_install -C build

%find_lang %{kaname} --all-name --with-kde --with-qm

%clean
rm -rf $RPM_BUILD_ROOT

%files -f %{kaname}.lang
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/step
%{_desktopdir}/org.kde.step.desktop
%{_datadir}/config.kcfg/step.kcfg
%{_iconsdir}/hicolor/128x128/apps/step.png
%{_iconsdir}/hicolor/16x16/apps/step.png
%{_iconsdir}/hicolor/22x22/actions/pointer.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Anchor.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Box.png
%{_iconsdir}/hicolor/22x22/actions/step_object_ChargedParticle.png
%{_iconsdir}/hicolor/22x22/actions/step_object_CircularMotor.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Controller.png
%{_iconsdir}/hicolor/22x22/actions/step_object_CoulombForce.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Disk.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Gas.png
%{_iconsdir}/hicolor/22x22/actions/step_object_GasParticle.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Graph.png
%{_iconsdir}/hicolor/22x22/actions/step_object_GravitationForce.png
%{_iconsdir}/hicolor/22x22/actions/step_object_LinearMotor.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Meter.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Note.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Particle.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Pin.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Polygon.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Rope.png
%{_iconsdir}/hicolor/22x22/actions/step_object_SoftBody.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Spring.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Stick.png
%{_iconsdir}/hicolor/22x22/actions/step_object_Tracer.png
%{_iconsdir}/hicolor/22x22/actions/step_object_WeightForce.png
%{_iconsdir}/hicolor/22x22/apps/step.png
%{_iconsdir}/hicolor/32x32/apps/step.png
%{_iconsdir}/hicolor/48x48/apps/step.png
%{_iconsdir}/hicolor/64x64/apps/step.png
%{_datadir}/metainfo/org.kde.step.appdata.xml
%{_datadir}/step
%{_datadir}/mime/packages/org.kde.step.xml
%{_datadir}/knsrcfiles/step.knsrc
%changelog
* Tue Apr 23 2024 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/ka5-step.git;a=log;h=master

* Fri Mar 15 2024 Witold Filipczyk <witekfl@poczta.onet.pl> c634fa3
- updated to 23.08.5

* Fri Mar 15 2024 Witold Filipczyk <witekfl@poczta.onet.pl> 8f7bbc7
- Revert "- 24.01.95"

* Sun Feb 25 2024 Witold Filipczyk <witekfl@poczta.onet.pl> dc6340f
- 24.01.95

* Fri Dec 08 2023 Witold Filipczyk <witekfl@poczta.onet.pl> bdf4b3a
- updated to 23.08.4

* Fri Nov 10 2023 Witold Filipczyk <witekfl@poczta.onet.pl> ea65469
- updated to 23.08.3

* Fri Oct 13 2023 Witold Filipczyk <witekfl@poczta.onet.pl> 494baa7
- updated to 23.08.2

* Fri Sep 15 2023 Witold Filipczyk <witekfl@poczta.onet.pl> 6bfeab4
- updated to 23.08.1

* Thu Aug 24 2023 Witold Filipczyk <witekfl@poczta.onet.pl> d46c820
- updated to 23.08.0; cmake -B build

* Fri Jul 07 2023 Witold Filipczyk <witekfl@poczta.onet.pl> bb13dd5
- updated to 23.04.3

* Sat Jun 10 2023 Witold Filipczyk <witekfl@poczta.onet.pl> 7c42d15
- updated to 23.04.2

* Fri May 12 2023 Witold Filipczyk <witekfl@poczta.onet.pl> 3f011bf
- updated to 23.04.1

* Fri Apr 21 2023 Witold Filipczyk <witekfl@poczta.onet.pl> f94d381
- updated to 23.04.0

* Sun Apr 09 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> fcf0306
- rebuild against QT 5.15.9

* Fri Mar 03 2023 Witold Filipczyk <witekfl@poczta.onet.pl> 7a196f9
- updated to 22.12.3

* Fri Feb 03 2023 Witold Filipczyk <witekfl@poczta.onet.pl> af28884
- updated to 22.12.2

* Fri Jan 06 2023 Witold Filipczyk <witekfl@poczta.onet.pl> e359dd6
- updated to 22.12.1

* Thu Jan 05 2023 Krzysztof Mrozowicz <mrozowik@pld-linux.org> 5da5b08
- rebuild against QT 5.15.8

* Thu Dec 08 2022 Witold Filipczyk <witekfl@poczta.onet.pl> 4161fbd
- updated to 22.12.0
- added python.patch

* Thu Dec 08 2022 Witold Filipczyk <witekfl@poczta.onet.pl> 870cbf7
- /usr/bin/python was found instead of python3

* Fri Nov 04 2022 Witold Filipczyk <witekfl@poczta.onet.pl> 1d526f5
- updated to 22.08.3

